@@ -30,11 +30,6 @@ class Workflow:
         wkf.run()
         ...
   """
-  @staticmethod
-  def _format_logline(prefix, message, indent):
-    dashlen = 74 - len(prefix) - len(message) - indent
-    return f"{' ' * indent}- [{prefix}] {message} {'-' * dashlen}"
-
   def __init__(self, name, context):
     self.name = name
     self.context = context
@@ -51,6 +46,8 @@ class Workflow:
                                session=self.session)
 
   def __enter__(self):
+    logging.getLogger().log_section("WORKFLOW",
+                                    f"Started {self.name} / {self.session}")
     self.history.__enter__()
     self.context.install_packages()
     return self
@@ -69,16 +66,15 @@ class Workflow:
     self.context.logger.remove_file_handler(self.session)
 
   def _instantiate(self, module, cls, args):
-    logging.info(f"    [+] Object instantiation: {module}.{cls}")
+    logging.info(f"[+] Object instantiation: {module}.{cls}")
     return self.context.modulemgr.get_class_from_module(cls=cls,
                                                         module=module)(args=args)
 
   def run(self):
     """Run the workflow."""
-    logging.info(f"  [+] Running workflow: [{self.name}] {self.session}")
     for step in self.context.configmgr.get_parameter("workflow",
                                                      "$.laboro.workflow.steps"):
-      logging.info(Workflow._format_logline("STEP", step['name'], 2))
+      logging.getLogger().log_section("STEP", step['name'])
       module = step["module"]["name"]
       cls_args = step["module"]["args"]
       cls = step["module"]["class"]
@@ -90,6 +86,8 @@ class Workflow:
         self.context.register_method_secrets(instance,
                                              action["method"],
                                              action_args)
-        logging.info(Workflow._format_logline("ACTION", action['method'], 4))
+        logging.getLogger().log_section("ACTION",
+                                        f"{step['name']} / {action['method']}")
         getattr(instance, action["method"])(**action_args)
         time.sleep(2)
+    logging.getLogger().log_section("WORKFLOW", "No more steps to run")
